@@ -16,9 +16,8 @@ def gen_sin(n=1000):
     fs = 8000  # Sample rate
     f = 50
     x = np.arange(n)
-    y = np.sin(2 * np.pi * f * x / fs)
 
-    return y
+    return np.sin(2 * np.pi * f * x / fs)
 
 
 def gen_sign(n=1000, periods=220):
@@ -32,9 +31,8 @@ def gen_sign(n=1000, periods=220):
     """
 
     sin = gen_sin(n=n)
-    data = np.sign(sin)
 
-    return data
+    return np.sign(sin)
 
 
 # Random
@@ -48,9 +46,7 @@ def gen_random(n=1000):
         np.ndarray: Random test data.
     """
 
-    data = np.random.randn(n) * 5 + 10
-
-    return data
+    return np.random.randn(n) * 5 + 10
 
 
 # Range
@@ -64,6 +60,4 @@ def gen_slope(n=1000):
         np.ndarray: Slope test data.
     """
 
-    data = np.array(range(n))
-
-    return data
+    return np.array(range(n))
